==> PPDF_1_0.zip: PubMedPDF/language/japanese/main.php <==
<?php

define("_MD_PDF_A","PDFåץ");
define("_MD_PDF_A_DESC"," ե̾PMID.pdfפȤƥåץɤ뤳ȤˤϿޤ");
define("_MD_PDF_B","PMIDǤϿ");
define("_MD_PDF_B_DESC"," PDFե뤬ʤƤ⤳PMIDϤϿޤ<br>եɲååץɤϡPDF uploadפǲǽǤ");
define("_MD_PDF_C","ϿʥåץɺѤߤΥǡоݡ");
define("_MD_PDF_C_DESC"," åץɺѤߤΥǡϿޤ<br>ˤäƤϤʤ֤ΤǵĹˤԤ");
define("_MD_PDF_D","ϿPMIDΤϿǡоݡ");
define("_MD_PDF_D_DESC"," ݡȤǺǡ򸵤PMIDΤ߰Ͽޤ");
define("_MD_PDF_E","ꥹȥݡ");
define("_MD_PDF_E_DESC","ϿƤǡΥꥹȤ뤳Ȥޤ<br>ΥեΰϿǻꤷϿƲ");
define("_MD_L1","PDFʤǡ");
define("_MD_L2","PDFǡ");
define("_MD_L3","");
define("_MD_L4","ʬϿǡΤ");
define("_MD_PDF_F","ǡõ");
define("_MD_PDF_F_DESC","ְäϿǡϤPMIDϤоõ뤳Ȥޤ");

define("_MD_WO_A","ʸ");
define("_MD_JOUR_REG","㡼ʥ/ҡϿ");
define("_MD_JOUR_EDIT","㡼ʥ/ҡ");
define("_MD_REMOVE_INFO","ʸõ");
define("_MD_EDIT_INFO","ʸ");
define("_MD_REGISTER_AUTO","ưϿ");
define("_MD_REGISTER_AUTOINFO","\"uploads_xml\" ǥ쥯ȥˤXMLեѤƼưϿԤ");
define("_MD_REG_RESULT","Ͽ");

define("_MD_XML_DOWNLOAD","XML֤Υ");
define("_MD_XML_DOWNLOAD_DESC","ʸǡXMLե뤬äƤޤ");

define("_MD_FAVORITE_MKDIR","ǥ쥯ȥ");
define("_MD_FAVORITE_DIRLIST","ǥ쥯ȥ");
define("_MD_FAVORITE_DIRTOP","ȥåץǥ쥯ȥ");

define("_MD_NOTE","");
define("_MD_NOTE_PRI","");
define("_MD_NOTE_PUB","");
define("_MD_NOTE_NEW","");
define("_MD_NOTE_NEW2","Ͽ");
define("_MD_NOTE_CLOSE","Ĥ");
define("_MD_NOTE_ADDED","嵭Υ⤬Ͽޤ");
define("_MD_NOTE_EDIT","Խ");
define("_MD_NOTE_EDITED","⤬ѹޤ");
define("_MD_NOTE_EDIT_D","ӽ");
define("_MD_NOTE_EDIT_C","Խ");
define("_MD_NOTE_PERMISSION_ERROR","ΥԽ븢¤ޤ");
define("_MD_NOTE_NODATA_ERROR","ʤλꤷ¸ߤޤ");
define("_MD_NOTE_DEL","ΥӽƤǤ");
define("_MD_NOTE_DELETED","ӽޤ");

define("_MD_SCUT","硼ȥåȺ");
define("_MD_SCUT_MADE","ΥڡؤΥ硼ȥåȤޤ");

define("_MD_FAVO_ADD","Ͽ");
define("_MD_FAVO_WHICHD","ɤΥǥ쥯ȥϿޤ");
define("_MD_FAVO_ADDED","Ͽޤ");

define("_MD_CHECK_ALL","");
define("_MD_DELETE","ӽ");
define("_MD_INSERTINTO","ذư");
define("_MD_ADD_BIBLIO","ʸꥹȤɲ");

define("_MD_BIBLIO","ʸ");
define("_MD_BIBLIO_EXIST","ΥǡʸꥹȤˤޤ");
define("_MD_BIBLIO_EXPORT","Ϥ");

define("_MD_PubMedSearch","PubMed ");
define("_MD_PubMedSearch_unin_submit","åǡ򱣤 or ɽ");
define("_MD_PubMedSearch_regist_submit","åǡϿ");

?>

==> PPDF_1_2.zip: PubMedPDF/language/japanese/main.php <==
<?php

define("_MD_PDF_A","PDFåץ");
define("_MD_PDF_A_DESC"," ե̾PMID.pdfפȤƥåץɤ뤳ȤˤϿޤ");
define("_MD_PDF_B","PMIDǤϿ");
define("_MD_PDF_B_DESC"," PDFե뤬ʤƤ⤳PMIDϤϿޤ<br>եɲååץɤϡPDF uploadפǲǽǤ");
define("_MD_PDF_C","ϿʥåץɺѤߤΥǡоݡ");
define("_MD_PDF_C_DESC"," åץɺѤߤΥǡϿޤ<br>ˤäƤϤʤ֤ΤǵĹˤԤ");
define("_MD_PDF_D","ϿPMIDΤϿǡоݡ");
define("_MD_PDF_D_DESC"," ݡȤǺǡ򸵤PMIDΤ߰Ͽޤ");
define("_MD_PDF_E","ꥹȥݡ");
define("_MD_PDF_E_DESC","ϿƤǡΥꥹȤ뤳Ȥޤ<br>ΥեΰϿǻꤷϿƲ");
define("_MD_L1","PDFʤǡ");
define("_MD_L2","PDFǡ");
define("_MD_L3","");
define("_MD_L4","ʬϿǡΤ");
define("_MD_PDF_F","ǡõ");
define("_MD_PDF_F_DESC","ְäϿǡϤPMIDϤоõ뤳Ȥޤ");

define("_MD_WO_A","ʸ");
define("_MD_JOUR_REG","㡼ʥ/ҡϿ");
define("_MD_JOUR_EDIT","㡼ʥ/ҡ");
define("_MD_REMOVE_INFO","ʸõ");
define("_MD_EDIT_INFO","ʸ");
define("_MD_REGISTER_AUTO","ưϿ");
define("_MD_REGISTER_AUTOINFO","\"uploads_xml\" ǥ쥯ȥˤXMLեѤƼưϿԤ");
define("_MD_REG_RESULT","Ͽ");

define("_MD_XML_DOWNLOAD","XML֤Υ");
define("_MD_XML_DOWNLOAD_DESC","ʸǡXMLե뤬äƤޤ");

define("_MD_FAVORITE_MKDIR","ǥ쥯ȥ");
define("_MD_FAVORITE_DIRLIST","ǥ쥯ȥ");
define("_MD_FAVORITE_DIRTOP","ȥåץǥ쥯ȥ");

define("_MD_NOTE","");
define("_MD_NOTE_PRI","");
define("_MD_NOTE_PUB","");
define("_MD_NOTE_NEW","");
define("_MD_NOTE_NEW2","Ͽ");
define("_MD_NOTE_CLOSE","Ĥ");
define("_MD_NOTE_ADDED","嵭Υ⤬Ͽޤ");
define("_MD_NOTE_EDIT","Խ");
define("_MD_NOTE_EDITED","⤬ѹޤ");
define("_MD_NOTE_EDIT_D","ӽ");
define("_MD_NOTE_EDIT_C","Խ");
define("_MD_NOTE_PERMISSION_ERROR","ΥԽ븢¤ޤ");
define("_MD_NOTE_NODATA_ERROR","ʤλꤷ¸ߤޤ");
define("_MD_NOTE_DEL","ΥӽƤǤ");
define("_MD_NOTE_DELETED","ӽޤ");
define("_MD_NOTE_ATTACHED","źեե");
define("_MD_NOTE_ATTACHED_EDIT","źեեѹ or ɲ");
define("_MD_NOTE_ATTACHED_DEL","źեեӽ");
define("_MD_NOTE_ATTACHED_DELETED","źեեӽޤ");
define("_MD_NOTE_ATTACHED_ADDED","ե뤬åץɤޤ");


define("_MD_SCUT","硼ȥåȺ");
define("_MD_SCUT_MADE","ΥڡؤΥ硼ȥåȤޤ");

define("_MD_FAVO_ADD","Ͽ");
define("_MD_FAVO_WHICHD","ɤΥǥ쥯ȥϿޤ");
define("_MD_FAVO_ADDED","Ͽޤ");

define("_MD_CHECK_ALL","");
define("_MD_DELETE","ӽ");
define("_MD_INSERTINTO","ذư");
define("_MD_ADD_BIBLIO","ʸꥹȤɲ");

define("_MD_BIBLIO","ʸ");
define("_MD_BIBLIO_EXIST","ΥǡʸꥹȤˤޤ");
define("_MD_BIBLIO_EXPORT","Ϥ");

define("_MD_PubMedSearch","PubMed ");
define("_MD_PubMedSearch_unin_submit","åǡ򱣤 or ɽ");
define("_MD_PubMedSearch_regist_submit","åǡϿ");

?>
